######################################################################
#:ClearCase Perl API 
#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2001, 2008 All Rights Reserved
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
#
# Copyright 2001,2008 Rational Software Corporation. All Rights Reserved
# This software contains proprietary and confidential information of
# Rational and its suppliers.  Use, disclosure or reproduction is
# prohibited without the prior express written consent of Rational.

=head1 NAME

CQCC::CCPerlAPI - ClearCase Interface using CtCmd Perl API

=head1 CLASS DESCRIPTION

This class manages an interface to ClearCase using the CtCmd Perl API
instead of using ClearTool processes directly. In order to be used,
the CtCmd.pm package must be present in the @INC Perl path and the
configuration file must ask for it as the ClearCaseInterface class as
shown below:

    &SetConfigParm("ClearCaseInterface", "CQCC::CCPerlAPI");

SUPPORT POLICY: See TriggerCQCC.pm for the Rational Support Policy. 

=head1 METHODS

=cut

######################################################################
#::Package CQCC::CCPerlAPI
######################################################################

package CQCC::CCPerlAPI;
use CQCC::CCase;
@ISA = qw( CQCC::CCase );

use strict;
sub Version { return '2.1' };

use CtCmd;
use CQCC::IOBase;
use CQCC::Parm;

######################################################################
#::function ClassTest

=over 6

=item C<ClassTest(@args)>

This function will create an instance of the class then invoke the
base ClassTest function to run unit tests.

=back

=cut

######################################################################

sub ClassTest {
    my @args = @_;
    &ForceParm("ClearCaseInterface", "CQCC::CCPerlAPI");

    return &CQCC::CCase::ClassTest(@args);
}

######################################################################
#::method new

=over 6

=item C<new()>

This method creates a new CCPerlAPI object. Since no initialization
is required, it just creates the object instance.

=back

=cut

######################################################################

sub new { 
   my $proto = shift;
   my $class = ref($proto) || $proto;  # Object or class name

   # Attributes
   my $self;

   # CCperl doesn't support SUPER so use direct reference to parent
   $self = new CQCC::CCase();

   $self->{CLASSNAME} = "CQCC::CCPerlAPI";
   bless($self, $class);
   return $self;
}

######################################################################
#::method PostCommand

=over 6

=item C<PostCommand($operation)>

This method will send the provided $operation string to the main
entry function for the CtCmd package to execute it as a ClearCase
command. It returns an array of output lines. 

@data = $obj->PostCommand($cmd);

=back

=cut

######################################################################

sub PostCommand {
    my ($self,$operation) = @_;
    my ($package, $filename, $line) = caller;

    &IODebugPrint("DETAILED",
                  "*PostCommand: ($filename)\n   $operation\n");

    my @result = CtCmd::ct($operation);
    &IODebugPrint("DETAILED",
                  "PostCommand: $result[0]\n   $result[1]\n");

    my @resultLines = split("\n",$result[0]);
    return @resultLines;
}

######################################################################
#::Tail
######################################################################

1;
